/*
 * circlepi.c
 *
 * Computes an approximation of Pi through a disk area
 *
 * Compile with: gcc -Ofast -Wall circlepi.c -o circlepi
 * Execute with: ./circlepi 1000
 *
 * Author: Xavier Bourgeois - xavier@monorailc.at
 * License: Creative Commons - BY-NC
 * Article: https://monorailc.at/cms/2025-05-20-comparaison-de-langages-de-programmation--5----autre-algorithme.html
 * Date: 2025-05-17
 */

#include <stdio.h>
#include <stdlib.h>
#include <limits.h>
#include <math.h>

unsigned long compute_int32(int n) {
	unsigned long count = 0;
	int i, j;

	for(i = -n; i <= n; i++) {
		for(j = -n; j <= n; j++) {
			if(i*i + j*j < n*n) {
				count++;
			}
		}
	}
	return count;
}

unsigned long compute_int64(long int n) {
	unsigned long count = 0;
	long int i, j; // computation with long ints is 3 times slower

	for(i = -n; i <= n; i++) {
		for(j = -n; j <= n; j++) {
			if(i*i + j*j < n*n) {
				count++;
			}
		}
	}
	return count;
}

int main(int argc, char **argv) {
	unsigned long count;
	long n;

	if(argc < 1)
		return 1;
	n = (int) abs(atoi(argv[1]));
	if(2*n*n > INT_MAX) {	// 2*n*n >= UINT_MAX -> use long ints to avoid overflows, triggers at 32767
		count = compute_int64(n);
	}
	else
		count = compute_int32((int) n);

	//printf("%.16lf\n", (double) count / (n*n));
	printf("%ld\t%.16lf\t%.16lf\n", n, (double) count / (n*n), M_PI - (double) count / (n*n));
	return 0;
}
