/*
 * circlepi.cpp
 *
 * Computes an approximation of Pi through a disk area
 *
 * Compile with: g++ -Ofast -Wall -std=c++20 circlepi.cpp -o circlepi_cpp
 * Execute with: ./circlepi_cpp 1000
 *
 * Author: Xavier Bourgeois - xavier@monorailc.at
 * License: Creative Commons - BY-NC
 * Article: https://monorailc.at/cms/2025-05-20-comparaison-de-langages-de-programmation--5----autre-algorithme.html
 * Date: 2025-05-17
 */

#include <iostream>
#include <cmath>
#include <cstdio>
#include <climits>

//#define ABS(x) x>0?x:-x // unused, no major difference

unsigned long compute_int(auto n) {
	unsigned long count = 0;

	for(auto i = -n; i <= n; i++) {
		for(auto j = -n; j <= n; j++) {
			if(i*i + j*j < n*n) {
				count++;
			}
		}
	}
	return count;
}

int main(int argc, char **argv) {
	unsigned long count;

	if(argc < 1)
		return 1;
	long n = abs(atoi(argv[1]));
	if(2*n*n < INT_MAX)
		count = compute_int((int)n);
	else
		count = compute_int((long)n);
	std::cout<<n<<'\t'<<(double) count / (n*n)<<'\t'<<M_PI - (double) count / (n*n)<<'\n';
	return 0;
}
