/*
 * circlepi.go
 *
 * Computes an approximation of Pi through a disk area
 *
 * Compile with: go build circlepi.go
 * Execute with: ./circlepi 1000
 *
 * Author: Xavier Bourgeois - xavier@monorailc.at
 * License: Creative Commons - BY-NC
 * Article: https://monorailc.at/cms/2025-05-20-comparaison-de-langages-de-programmation--5----autre-algorithme.html
 * Date: 2025-05-17
 */

package main

import "fmt"
import "math"
import "os"
import "strconv"

func circlepi(n int) int {
	var count = 0

	for i := -n; i <= n; i++ {
		for j := -n; j <= n; j++ {
			if i*i + j*j < n*n {
				count++;
			}
		}
	}
	return count;
}


func main() {
	var n int
	var count = 0

	if len(os.Args) < 2 {
		os.Exit(1)
	}
	n, err := strconv.Atoi(os.Args[1])

	if n < 0 || err != nil {
		os.Exit(1)
	}

	count = circlepi(n)
	fmt.Printf("%v\t%v\t%v\n", n, float64(count)/float64(n*n), math.Pi - float64(count)/float64(n*n))
	os.Exit(0)
}
