/*
 * circlepi.rs
 *
 * Computes an approximation of Pi through a disk area
 *
 * Compile with: cargo build
 * Execute with: ./circlepi 1000
 *
 * Author: Xavier Bourgeois - xavier@monorailc.at
 * License: Creative Commons - BY-NC
 * Article: https://monorailc.at/cms/2025-05-20-comparaison-de-langages-de-programmation--5----autre-algorithme.html
 * Date: 2025-05-19
 */

use std::env;
use std::process;
use std::f64::consts::PI;
/*
fn compute_pi_i32(n: i32) -> i64 {  //actually slower than i64
	let mut count: i64 = 0;

	for _i in -n..n {
        for _j in -n..n {
            count += (_i*_i+_j*_j < n*n) as i64;
        }
	}
	return count;
}*/

fn compute_pi_i64(n: i64) -> i64 {
	let mut count: i64 = 0;

	for _i in -n..n {
        for _j in -n..n {
            count += (_i*_i+_j*_j < n*n) as i64;
        }
	}
	return count;
}



fn main() {
	let n;
    //let count : i64;

	if env::args().len() < 2 {
		println!("fail");
		process::exit(1);
	}
	let argv: Vec<String> = env::args().collect();
	n = argv[1].parse::<i64>().unwrap();
	if n < 1 {
		println!("fail");
		process::exit(1);
	}
	let count = compute_pi_i64(n);
	/*if 2*n*n < i32::MAX.into() {
        count = compute_pi_i32(n as i32);   //actually slower than i64
    }
    else {
        count = compute_pi_i64(n);
    }*/

	//println!("{}", (count as f64) / (n*n) as f64);
	println!("{}\t{}\t{}", n, (count as f64) / (n*n) as f64, PI - (count as f64) / (n*n) as f64);
	process::exit(0);
}
