#!/bin/bash
# circlepi.sh
#
# Computes an approximation of Pi through a disk area
#
# Execute with: bash circlepi.sh 100
# Warning: very slow
#
# Author: Xavier Bourgeois - xavier@monorailc.at
# License: Creative Commons - BY-NC
# Article: https://monorailc.at/cms/2025-05-20-comparaison-de-langages-de-programmation--5----autre-algorithme.html
# Date: 2025-05-19
#
# Useful links:
# [1] https://stackoverflow.com/questions/17336915/return-value-in-a-bash-function

compute_pi() {
	local count=0
	local n=$1
	for i in $(seq -$n $n);
		do for j in $(seq -$n $n);
		do let circle=$i**2+$j**2
		let nsquared=$n*$n
		if [ $circle -lt $nsquared ]; then
			let count=$count+1
			fi
		done
	done
	echo $count # return syntax is confusing, see [1]
}

if [ ! ${BASH_ARGC} -eq 1 ]; then
	exit 1
fi

if [ ! ${BASH_ARGV[0]} -gt 0 ]; then
	exit 1
fi

let n=${BASH_ARGV[0]}
count=$(compute_pi $n)

#pi=$(awk "BEGIN { print $count / ($n * $n) }")	# made prettier below
pi=$(awk "BEGIN { printf \"%g\t%.16g\t%.16g\n\", $n, $count / ($n * $n), 3.14159265358979323846 - $count / ($n * $n) }")	# using M_PI from <math.h>
echo $pi
